lilypondparsertools.LilyPondLexicalDefinition
=============================================

.. abjad-lineage:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition

.. autoclass:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.push_signature
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.scan_bare_word
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.scan_escaped_word
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_651_a
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_651_b
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_661
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_666
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_ANY_165
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_643
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_646
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_210
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_214
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_216
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_218
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_220
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_222
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_227
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_353
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_notes_233
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_notes_387
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_notes_390
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_notes_396
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_notes_399
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_notes_686
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_error
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_longcomment_291
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_longcomment_293
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_longcomment_296
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_longcomment_error
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_markup_545
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_markup_548
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_markup_601
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_markup_error
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_newline
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_notes_417
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_notes_421
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_notes_424
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_notes_428
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_notes_428b
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_notes_433
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_notes_error
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_quote_440
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_quote_443
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_quote_446
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_quote_456
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_quote_XXX
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_quote_error
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_scheme_error
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_version_242
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_version_278
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_version_341
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_version_error
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.__eq__
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.__format__
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.__hash__
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.__ne__
      ~abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Methods
-------

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.push_signature
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.scan_bare_word
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.scan_escaped_word
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_651_a
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_651_b
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_661
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_666
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_ANY_165
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_643
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_646
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_210
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_214
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_216
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_218
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_220
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_222
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_227
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_markup_notes_353
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_notes_233
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_notes_387
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_notes_390
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_notes_396
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_notes_399
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_INITIAL_notes_686
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_error
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_longcomment_291
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_longcomment_293
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_longcomment_296
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_longcomment_error
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_markup_545
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_markup_548
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_markup_601
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_markup_error
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_newline
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_notes_417
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_notes_421
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_notes_424
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_notes_428
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_notes_428b
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_notes_433
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_notes_error
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_quote_440
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_quote_443
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_quote_446
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_quote_456
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_quote_XXX
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_quote_error
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_scheme_error
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_version_242
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_version_278
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_version_341
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.t_version_error
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.__hash__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondLexicalDefinition.LilyPondLexicalDefinition.__repr__
   :noindex:
